#ifndef AGENT_DAEMONIZING_H
#define AGENT_DAEMONIZING_H

#include <fcntl.h>

pid_t daemonize(unsigned char deep);

#endif  // AGENT_DAEMONIZING_H
